==> SQLiteCSLib_Src_1_4.zip: SQLiteCSLib_Src_1_4/1.x/osqlite/osqlite3_if.cpp <==
/*
*** SQLITE3 bp[
***
*** CC^[tF[X GLX|[g
*/

#include "stdafx.h"

/*
*** CX^X쐬
*/
__EXPORT osqlite3* WINAPI osqlite3_new()
{
	return new osqlite3();
}

/*
*** CX^Xj
*/ 
__EXPORT void WINAPI osqlite3_delete( osqlite3* instance )
{
	delete instance;
}

/*
*** ڑI[v
*** filename : t@C(f[^x[XpX)
*/
__EXPORT bool WINAPI osqlite3_open( osqlite3* instance, wchar_t* filename )
{
	return instance->open( filename );
}

/*
*** ؒf
*/
__EXPORT void WINAPI osqlite3_close( osqlite3* instance )
{
	instance->close();
}

/*
*** ŏIG[R[h擾
*/
__EXPORT int WINAPI osqlite3_getLastErr( osqlite3* instance )
{
	return instance->getLastErr();
}

/*
*** ŏIG[bZ[W擾
*/
__EXPORT const wchar_t* WINAPI osqlite3_getLastErrMsg( osqlite3* instance )
{
	return instance->getLastErrMsg();
}

/*
*** f
*/
__EXPORT void WINAPI osqlite3_interrupt( osqlite3* instance )
{
	instance->interrupt();
}

/*
*** XVes
*/
__EXPORT int WINAPI osqlite3_changes( osqlite3* instance )
{
	return instance->changes();
}

#ifdef _WIN32_WCE
/*
*** [U`֐쐬
*/
__EXPORT int WINAPI osqlite3_createfunction( osqlite3* instance, wchar_t* funcname, int iarg, int eTextRep, 
		HANDLE clrevent, osqlite3func** instancepoint, bool xFunc, bool xStep, bool xFinal )
{
	return instance->createfunction( funcname, iarg, eTextRep, clrevent, instancepoint, xFunc, xStep, xFinal );
}

/*
*** R[obN擾
*/
__EXPORT int WINAPI osqlite3func_GetCallBackParam( osqlite3func* instancepoint, int* pargc )
{
	return instancepoint->GetCallBackParam( pargc );
}

/*
*** ^擾
*/
__EXPORT int WINAPI osqlite3func_GetParamType( osqlite3func* instancepoint, int iNo )
{
	return instancepoint->GetParamType( iNo );
}

/*
*** ^擾
*/
__EXPORT int WINAPI osqlite3func_GetParamInt( osqlite3func* instancepoint, int iNo )
{
	return instancepoint->GetParamInt( iNo );
}

/*
*** _^擾
*/
__EXPORT void WINAPI osqlite3func_GetParamDouble( osqlite3func* instancepoint, int iNo, double* pResult )
{
	*pResult = instancepoint->GetParamDouble( iNo );
}

/*
*** ^擾
*/
__EXPORT const wchar_t* WINAPI osqlite3func_GetParamText( osqlite3func* instancepoint, int iNo )
{
	return instancepoint->GetParamText( iNo );
}

/*
*** oCi^擾
*/
__EXPORT const void* WINAPI osqlite3func_GetParamBlob( osqlite3func* instancepoint, int iNo, int* piLen )
{
	return instancepoint->GetParamBlob( iNo, piLen );
}

/*
*** R[obN
*/
__EXPORT void WINAPI osqlite3func_FinishCallBackParam( osqlite3func* instancepoint )
{
	instancepoint->FinishCallBackParam();
}

/*
*** ^ʃZbg
*/
__EXPORT void WINAPI osqlite3func_SetResultInt( osqlite3func* instancepoint, int val )
{
	instancepoint->SetResultInt( val );
}

/*
*** _^ʃZbg
*/
__EXPORT void WINAPI osqlite3func_SetResultDouble( osqlite3func* instancepoint, double* pVal )
{
	instancepoint->SetResultDouble( *pVal );
}

/*
*** ^ʃZbg
*/
__EXPORT void WINAPI osqlite3func_SetResultText( osqlite3func* instancepoint, wchar_t* val, int ilen )
{
	instancepoint->SetResultText( val, ilen );
}

/*
*** ^ʃZbg
*/
__EXPORT void WINAPI osqlite3func_SetResultBlob( osqlite3func* instancepoint, void* val, int ilen )
{
	instancepoint->SetResultBlob( val, ilen );
}
#else
/*
*** [U`֐쐬
*/
__EXPORT int WINAPI osqlite3_createfunction( osqlite3* instance, wchar_t* funcname, int iarg, int eTextRep, 
		void (WINAPI *xFunc)(sqlite3_context*,int,sqlite3_value**),
		void (WINAPI *xStep)(sqlite3_context*,int,sqlite3_value**),
		void (WINAPI *xFinal)(sqlite3_context*) )
{
	return instance->createfunction( funcname, iarg, eTextRep, xFunc, xStep, xFinal );
}
#endif

#ifdef _WIN32_WCE
/*
*** [U`ƍ֐쐬
*/
__EXPORT int WINAPI osqlite3_createcollation( osqlite3* instance, wchar_t* funcname, int eTextRep, 
		HANDLE clrevent, osqlite3collation** instancepoint )
{
	return instance->createcollation( funcname, eTextRep, clrevent, instancepoint );
}

/*
*** R[obN擾
*/
__EXPORT void WINAPI osqlite3collation_GetCallBackParam( osqlite3collation* instancepoint, void** pNotUsed,int* pnKey1, void** ppKey1,int* pnKey2, void** ppKey2 )
{
	instancepoint->GetCallBackParam( pNotUsed, pnKey1, ppKey1, pnKey2, ppKey2 );
}

/*
*** R[obN
*/
__EXPORT void WINAPI osqlite3collation_FinishCallBackParam( osqlite3collation* instancepoint, int result )
{
	instancepoint->FinishCallBackParam( result );
}

#else
/*
*** [U`ƍ֐쐬
*/
__EXPORT int WINAPI osqlite3_createcollation( osqlite3* instance, wchar_t* funcname, int eTextRep, 
		int(WINAPI *xCompare)(void*,int,const void*,int,const void*) )
{
	return instance->createcollation( funcname, eTextRep, xCompare );
}
#endif

/*
*** sqlite3_value_typebv
*/
__EXPORT int WINAPI __sqlite3_value_type( sqlite3_value* context ) 
{
	return sqlite3_value_type( context );
}

/*
*** sqlite3_value_int64bv
*/
__EXPORT sqlite3_int64 WINAPI __sqlite3_value_int64( sqlite3_value* context ) 
{
	return sqlite3_value_int64( context );
}

/*
*** sqlite3_value_doublebv
*/
__EXPORT double WINAPI __sqlite3_value_double( sqlite3_value* context ) 
{
	return sqlite3_value_double( context );
}

/*
*** sqlite3_value_bytesbv
*/
__EXPORT int WINAPI __sqlite3_value_bytes( sqlite3_value* context ) 
{
	return sqlite3_value_bytes( context );
}

/*
*** sqlite3_value_blobbv
*/
__EXPORT const void* WINAPI __sqlite3_value_blob( sqlite3_value* context ) 
{
	return sqlite3_value_blob( context );
}

/*
*** sqlite3_value_text16bv
*/
__EXPORT const void* WINAPI __sqlite3_value_text16( sqlite3_value* context ) 
{
	return sqlite3_value_text16( context );
}

/*
*** sqlite3_result_intbv
*/
__EXPORT void WINAPI __sqlite3_result_int( sqlite3_context* context, int val ) 
{
	sqlite3_result_int( context, val );
}

/*
*** sqlite3_result_int64bv
*/
__EXPORT void WINAPI __sqlite3_result_int64( sqlite3_context* context, sqlite3_int64 val ) 
{
	sqlite3_result_int64( context, val );
}

/*
*** sqlite3_result_doublebv
*/
__EXPORT void WINAPI __sqlite3_result_double( sqlite3_context* context, double val ) 
{
	sqlite3_result_double( context, val );
}

/*
*** sqlite3_result_text16bv
*/
__EXPORT void WINAPI __sqlite3_result_text16( sqlite3_context* context, void* val, int ilen ) 
{
	sqlite3_result_text16( context, val, ilen, SQLITE_TRANSIENT );
}

/*
*** sqlite3_result_blobbv
*/
__EXPORT void WINAPI __sqlite3_result_blob( sqlite3_context* context, void* val, int ilen ) 
{
	sqlite3_result_blob( context, val, ilen, SQLITE_TRANSIENT );
}

#ifdef _WIN32_WCE
/*
*** 擾
*/
__EXPORT byte* WINAPI AllocHGlobal( size_t len )
{
	byte* mem = new byte[ len ];
	return mem;
}

/*
*** j
*/
__EXPORT void WINAPI FreeHGlobal( byte* pMem )
{
	delete [] pMem;
}
#endif

==> SQLiteCSLib_Src_1_5.zip: SQLiteCSLib_Src_1_5/1.x/osqlite/osqlite3_if.cpp <==
/*
*** SQLITE3 bp[
***
*** CC^[tF[X GLX|[g
*/

#include "stdafx.h"

/*
*** CX^X쐬
*/
__EXPORT osqlite3* WINAPI osqlite3_new()
{
	return new osqlite3();
}

/*
*** CX^Xj
*/ 
__EXPORT void WINAPI osqlite3_delete( osqlite3* instance )
{
	delete instance;
}

/*
*** o[W
*/
__EXPORT const char* WINAPI osqlite3_libversion( osqlite3* instance )
{
	return instance->libversion();
}

/*
*** ڑI[v
*** filename : t@C(f[^x[XpX)
*/
__EXPORT bool WINAPI osqlite3_open( osqlite3* instance, wchar_t* filename )
{
	return instance->open( filename );
}

/*
*** ؒf
*/
__EXPORT void WINAPI osqlite3_close( osqlite3* instance )
{
	instance->close();
}

/*
*** ŏIG[R[h擾
*/
__EXPORT int WINAPI osqlite3_getLastErr( osqlite3* instance )
{
	return instance->getLastErr();
}

/*
*** ŏIG[bZ[W擾
*/
__EXPORT const wchar_t* WINAPI osqlite3_getLastErrMsg( osqlite3* instance )
{
	return instance->getLastErrMsg();
}

/*
*** f
*/
__EXPORT void WINAPI osqlite3_interrupt( osqlite3* instance )
{
	instance->interrupt();
}

/*
*** XVes
*/
__EXPORT int WINAPI osqlite3_changes( osqlite3* instance )
{
	return instance->changes();
}

/*
*** ŏIǉROWID
*/
__EXPORT void WINAPI osqlite3_last_insert_rowid( osqlite3* instance, sqlite3_int64* val )
{
	*val = instance->last_insert_rowid();
}

#ifdef _WIN32_WCE
/*
*** [U`֐쐬
*/
__EXPORT int WINAPI osqlite3_createfunction( osqlite3* instance, wchar_t* funcname, int iarg, int eTextRep, 
		HANDLE clrevent, osqlite3func** instancepoint, bool xFunc, bool xStep, bool xFinal )
{
	return instance->createfunction( funcname, iarg, eTextRep, clrevent, instancepoint, xFunc, xStep, xFinal );
}

/*
*** R[obN擾
*/
__EXPORT int WINAPI osqlite3func_GetCallBackParam( osqlite3func* instancepoint, int* pargc )
{
	return instancepoint->GetCallBackParam( pargc );
}

/*
*** ^擾
*/
__EXPORT int WINAPI osqlite3func_GetParamType( osqlite3func* instancepoint, int iNo )
{
	return instancepoint->GetParamType( iNo );
}

/*
*** ^擾
*/
__EXPORT int WINAPI osqlite3func_GetParamInt( osqlite3func* instancepoint, int iNo )
{
	return instancepoint->GetParamInt( iNo );
}

/*
*** _^擾
*/
__EXPORT void WINAPI osqlite3func_GetParamDouble( osqlite3func* instancepoint, int iNo, double* pResult )
{
	*pResult = instancepoint->GetParamDouble( iNo );
}

/*
*** ^擾
*/
__EXPORT const wchar_t* WINAPI osqlite3func_GetParamText( osqlite3func* instancepoint, int iNo )
{
	return instancepoint->GetParamText( iNo );
}

/*
*** oCi^擾
*/
__EXPORT const void* WINAPI osqlite3func_GetParamBlob( osqlite3func* instancepoint, int iNo, int* piLen )
{
	return instancepoint->GetParamBlob( iNo, piLen );
}

/*
*** R[obN
*/
__EXPORT void WINAPI osqlite3func_FinishCallBackParam( osqlite3func* instancepoint )
{
	instancepoint->FinishCallBackParam();
}

/*
*** ^ʃZbg
*/
__EXPORT void WINAPI osqlite3func_SetResultInt( osqlite3func* instancepoint, int val )
{
	instancepoint->SetResultInt( val );
}

/*
*** _^ʃZbg
*/
__EXPORT void WINAPI osqlite3func_SetResultDouble( osqlite3func* instancepoint, double* pVal )
{
	instancepoint->SetResultDouble( *pVal );
}

/*
*** ^ʃZbg
*/
__EXPORT void WINAPI osqlite3func_SetResultText( osqlite3func* instancepoint, wchar_t* val, int ilen )
{
	instancepoint->SetResultText( val, ilen );
}

/*
*** ^ʃZbg
*/
__EXPORT void WINAPI osqlite3func_SetResultBlob( osqlite3func* instancepoint, void* val, int ilen )
{
	instancepoint->SetResultBlob( val, ilen );
}
#else
/*
*** [U`֐쐬
*/
__EXPORT int WINAPI osqlite3_createfunction( osqlite3* instance, wchar_t* funcname, int iarg, int eTextRep, 
		void (WINAPI *xFunc)(sqlite3_context*,int,sqlite3_value**),
		void (WINAPI *xStep)(sqlite3_context*,int,sqlite3_value**),
		void (WINAPI *xFinal)(sqlite3_context*) )
{
	return instance->createfunction( funcname, iarg, eTextRep, xFunc, xStep, xFinal );
}
#endif

#ifdef _WIN32_WCE
/*
*** [U`ƍ֐쐬
*/
__EXPORT int WINAPI osqlite3_createcollation( osqlite3* instance, wchar_t* funcname, int eTextRep, 
		HANDLE clrevent, osqlite3collation** instancepoint )
{
	return instance->createcollation( funcname, eTextRep, clrevent, instancepoint );
}

/*
*** R[obN擾
*/
__EXPORT void WINAPI osqlite3collation_GetCallBackParam( osqlite3collation* instancepoint, void** pNotUsed,int* pnKey1, void** ppKey1,int* pnKey2, void** ppKey2 )
{
	instancepoint->GetCallBackParam( pNotUsed, pnKey1, ppKey1, pnKey2, ppKey2 );
}

/*
*** R[obN
*/
__EXPORT void WINAPI osqlite3collation_FinishCallBackParam( osqlite3collation* instancepoint, int result )
{
	instancepoint->FinishCallBackParam( result );
}

#else
/*
*** [U`ƍ֐쐬
*/
__EXPORT int WINAPI osqlite3_createcollation( osqlite3* instance, wchar_t* funcname, int eTextRep, 
		int(WINAPI *xCompare)(void*,int,const void*,int,const void*) )
{
	return instance->createcollation( funcname, eTextRep, xCompare );
}
#endif

/*
*** sqlite3_value_typebv
*/
__EXPORT int WINAPI __sqlite3_value_type( sqlite3_value* context ) 
{
	return sqlite3_value_type( context );
}

/*
*** sqlite3_value_int64bv
*/
__EXPORT sqlite3_int64 WINAPI __sqlite3_value_int64( sqlite3_value* context ) 
{
	return sqlite3_value_int64( context );
}

/*
*** sqlite3_value_doublebv
*/
__EXPORT double WINAPI __sqlite3_value_double( sqlite3_value* context ) 
{
	return sqlite3_value_double( context );
}

/*
*** sqlite3_value_bytesbv
*/
__EXPORT int WINAPI __sqlite3_value_bytes( sqlite3_value* context ) 
{
	return sqlite3_value_bytes( context );
}

/*
*** sqlite3_value_blobbv
*/
__EXPORT const void* WINAPI __sqlite3_value_blob( sqlite3_value* context ) 
{
	return sqlite3_value_blob( context );
}

/*
*** sqlite3_value_text16bv
*/
__EXPORT const void* WINAPI __sqlite3_value_text16( sqlite3_value* context ) 
{
	return sqlite3_value_text16( context );
}

/*
*** sqlite3_result_intbv
*/
__EXPORT void WINAPI __sqlite3_result_int( sqlite3_context* context, int val ) 
{
	sqlite3_result_int( context, val );
}

/*
*** sqlite3_result_int64bv
*/
__EXPORT void WINAPI __sqlite3_result_int64( sqlite3_context* context, sqlite3_int64 val ) 
{
	sqlite3_result_int64( context, val );
}

/*
*** sqlite3_result_doublebv
*/
__EXPORT void WINAPI __sqlite3_result_double( sqlite3_context* context, double val ) 
{
	sqlite3_result_double( context, val );
}

/*
*** sqlite3_result_text16bv
*/
__EXPORT void WINAPI __sqlite3_result_text16( sqlite3_context* context, void* val, int ilen ) 
{
	sqlite3_result_text16( context, val, ilen, SQLITE_TRANSIENT );
}

/*
*** sqlite3_result_blobbv
*/
__EXPORT void WINAPI __sqlite3_result_blob( sqlite3_context* context, void* val, int ilen ) 
{
	sqlite3_result_blob( context, val, ilen, SQLITE_TRANSIENT );
}

#ifdef _WIN32_WCE
/*
*** 擾
*/
__EXPORT byte* WINAPI AllocHGlobal( size_t len )
{
	byte* mem = new byte[ len ];
	return mem;
}

/*
*** j
*/
__EXPORT void WINAPI FreeHGlobal( byte* pMem )
{
	delete [] pMem;
}
#endif
